# Azure Core Tracing OpenCensus client library for Python

This package has been deprecated and will no longer be maintained after 11-05-2024.

Please use the [Azure Core Tracing OpenTelemetry](https://pypi.org/project/azure-core-tracing-opentelemetry/) package for tracing support in Azure SDK libraries.
